@@ -5,8 +5,11 @@
 /* .Fortran calls */
 extern void F77_NAME(h2o92)(void *, void *, void *, void *);
 
+extern void F77_NAME(ideal2)(void *, void *, void *, void *, void *, void *, void *, void *);
+
 static const R_FortranMethodDef FortranEntries[] = {
     {"h2o92", (DL_FUNC) &F77_NAME(h2o92), 4},
+    {"ideal2", (DL_FUNC) &F77_NAME(ideal2), 8},
     {NULL, NULL, 0}
 };
 
